<?php

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

// Don't load if nileforest_framework_init is already defined
if (is_admin() && ! function_exists( 'nileforest_framework_init' ) ) :

function nileforest_framework_init() {
	//  If user can't edit theme options, exit
	if ( ! current_user_can( 'edit_theme_options' ) ) {
		return;
	}

	// Loads the required Options Framework classes.
	require plugin_dir_path( __FILE__ ) . 'inc/class-options-framework.php';
	require plugin_dir_path( __FILE__ ) . 'inc/class-options-framework-admin.php';
	require plugin_dir_path( __FILE__ ) . 'inc/class-options-interface.php';
	require plugin_dir_path( __FILE__ ) . 'inc/class-options-media-uploader.php';
	require plugin_dir_path( __FILE__ ) . 'inc/class-options-sanitization.php';


	// Instantiate the options page.
	$nileforest_framework_admin = new Nileforest_Framework_Admin;
	$nileforest_framework_admin->init();

	// Instantiate the media uploader class
	$nileforest_framework_media_uploader = new Nileforest_Framework_Media_Uploader;
	$nileforest_framework_media_uploader->init();

}
add_action( 'init', 'nileforest_framework_init', 20 );

endif;

/**
 * Helper function to return the theme option value.
 * If no value has been saved, it returns $default.
 * Needed because options are saved as serialized strings.
 *
 * Not in a class to support backwards compatibility in themes.
 */

if ( ! function_exists( 'theme_get_option' ) ) :
function theme_get_option( $name, $default = false ) {

	$option_name = '';

	// Gets option name as defined in the theme
	if ( function_exists( 'nileforest_framework_option_name' ) ) {
		$option_name = nileforest_framework_option_name();
	}

	// Fallback option name
	if ( '' == $option_name ) {
		$option_name = get_option( 'stylesheet' );
		$option_name = preg_replace( "/\W/", "_", strtolower( $option_name ) );
	}


	// Get option settings from database
	$options = get_option( $option_name );

	// Return specific option
	if ( isset( $options[$name] ) ) {
		return $options[$name];
	}

	return $default;
}

endif;

define( 'THEME_FRAMEWORK_DIR', get_template_directory_uri() . '/framework/' );

// Loads options.php from child or parent theme
$optionsfile = locate_template( 'framework/options.php' );
load_template( $optionsfile );